==> coreaction-2.8.0.tar.gz: coreaction-v2.8.0/app/main.cpp <==
/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QMessageBox>

#include <cprime/capplication.h>

#include "coreaction.h"


int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    CApplication app("CoreAction", argc, argv);

    if (app.isRunning()) {
		qDebug() << "Found a running instance. Exiting";
		QMessageBox::information(
            nullptr,
            "CoreAction",
            "CoreAction is already open. Click the tray icon to open the currently running one"
		);

		return 0;
	}

    app.setQuitOnLastWindowClosed(true);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreAction");

    coreaction e;
    e.show();

    return app.exec();
}

==> coreaction-2.9.0.tar.gz: coreaction-v2.9.0/app/main.cpp <==
/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QMessageBox>

#include <cprime/capplication.h>

#include "coreaction.h"


int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    CApplication app("CoreAction", argc, argv);

    if (app.isRunning()) {
		qDebug() << "Found a running instance. Exiting";
		QMessageBox::information(
            nullptr,
            "CoreAction",
            "CoreAction is already open. Click the tray icon to open the currently running one"
		);

		return 0;
	}

    app.setQuitOnLastWindowClosed(false);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreAction");

    coreaction e;
    e.show();

    return app.exec();
}
